@@ -26,9 +26,8 @@ def main():
                 out_socket.send_multipart(['message',
                                            session_id,
                                            'The time now is: ' + str(datetime.datetime.now())])
-                out_socket.send_multipart(['disconnect',
-                                           session_id,
-                                           ''])
+                out_socket.send_multipart(['disconnect', session_id, ''])
+                # out_socket.send_multipart(['disconnectall', '', ''])
     except KeyboardInterrupt:
         pass
 
